--encoding=utf-8

---------------------------------------
-- 事件管理
-- 销毁对象时，必须移除所有监听，否则不会被回收
---------------------------------------

Event = {}
Event.listeners = {}

-- 添加监听
Event.addListener = function(target,name,func)
	if Event.listeners[target] == nil then
		Event.listeners[target] = {}
	end
	if Event.listeners[target][name] == nil then
		Event.listeners[target][name] = {}
	end
	local listeners = Event.listeners[target][name]
	listeners[func] = true
end

-- 移除监听
Event.removeListener = function(target,name,func)
	if Event.listeners[target] == nil then
		return
	end
	local listeners = Event.listeners[target][name]
	if listeners == nil then
		return
	end
	listeners[func] = nil
end

-- 移除对象上所有监听
Event.removeAllListeners = function(target)
	Event.listeners[target] = nil
end

-- 触发某个事件
Event.trigger = function(target,name,arg)
	if Event.listeners[target] == nil then
		return
	end
	local listeners = Event.listeners[target][name]
	if listeners == nil then
		return
	end
	local event = {
		["name"] = name,
		["target"] = target,
		["arg"] = arg
	}
	for k,v in pairs(listeners) do
		event.func = k
		k(event)
	end
end


