--encoding=utf-8
-----------------------------------------------------------------------------
--| 字符串相关的一些处理
-----------------------------------------------------------------------------

-- 分割字符串
function splitString(str,delimiter)
   local args = {};
   local pattern = '(.-)' .. delimiter;
   local last_end = 1;
   local s,e,cap = string.find(str,pattern, 1);
   while s do
      if s ~= 1 or cap ~= '' then
		table.insert(args,cap);
      end
      last_end = e + 1;
      s,e,cap = string.find(str,pattern,last_end);
   end
   if last_end <= #str then
      cap = string.sub(str,last_end);
      table.insert(args,cap);
   end
   return args;
end

--去除字符串头部和尾部的空格 \t等
function trim(str)
	local tmp = string.gsub(str,"^%s+","")
	tmp = string.gsub(tmp,"%s+$","")
	return tmp
end
function splitWithTrim(str,delim)
	local args = {}
	local pattern = '(.-)' .. delim
	local last_end = 1
	local s,e,cap = string.find(str,pattern , 1)
	while s do
		local tmp = trim(cap)
		if tmp ~= '' then
			table.insert(args,tmp)
		end
		last_end = e+1
		s,e,cap = string.find(str,pattern,last_end)
	end
	if last_end <= #str then
		cap = trim(string.sub(str,last_end))
		if cap ~= "" then
			table.insert(args,cap)
		end
	end
	return args
end
--*****************************************
-- 切割字符串，返回数组 @author lihebin
--*****************************************
function cutString(str, c)
	local arr = {}
	local k = 1
	local i = 1
	local j = 1
	while j <= string.len(str) do
		if string.sub(str, j, j) == c then
			if i <= j-1 then
				arr[k] = string.sub(str, i, j-1)
				k = k+1
			end
			i = j+1
		elseif j == string.len(str) then
			arr[k] = string.sub(str, i, j)
			break
		end
		j = j+1
	end
	return arr
end

--***********************************************
--@desc repalce source[head, tail] with target
--@author yshen
--***********************************************
function replaceAt(source, head, tail, target)
	if head==1 then
		return target..string.sub(source, tail+1, -1)
	else 
		return string.sub(source, 1, head-1)..target..string.sub(source, tail+1, -1)
	end
end
--***********************************************
--@desc format a sql clause
--@note the same useage as Java String.format(sql, ...)
--@special without check of params
--@author yshen
--***********************************************		
--[[function formatSql(sql, ...)
	local ret = sql;
	local pattern = "\'%%"; --%在regex中有特殊含义，双百分号去除
	for i=1, select('#', ...) do
		local param = select(i, ...)
		local head, tail = string.find(ret, pattern)
		if head~=nil then
			local dOrs = string.sub(ret, tail+1, tail+1)
			if dOrs=="d" or dOrs=="f" then --replace '%d' '%f' with num
				ret = replaceAt(ret, head, tail+2, param)
			elseif dOrs=="s" then --replace '%s' with 'param'
				ret = replaceAt(ret, head+1, head+2, param);
			end
		end
	end
	return ret			
end--]]

--***********************************************
--@desc format a sql clause
--@note the same useage as Java String.format(sql, ...)
--@special without check of params
--@author yshen
--@desc 实现了Java String.format的简单功能，用于简化拼sql语句
--***********************************************
function formatSql(sql, ...)
	local ret = sql;
	local pattern = "%%"; --%在regex中有特殊含义，双百分号去除
	
	local currentHead = 1; --当前的搜索起始位置
	for i=1, select('#', ...) do
		local param = select(i, ...)
		local head, tail = string.find(ret, pattern, currentHead)--找到%
		if head==nil then
			assert(false, "error in formatSql, too many params")
		end	
		local spe = string.sub(ret, head, tail+1)

		if(spe=="%d" or spe=="%f" or spe=="%s") then--将%d, %f直接替换成参数，<b>目前没有加入参数类型检查</b>
			ret = replaceAt(ret, head, head+1, param)
			currentHead = head+string.len(tostring(param))
			--print(ret)
		else
			--assert(false, "error in sql, should not appear single %");
			currentHead = head+1
		end
	end
	return ret
end


